from os.path import dirname, abspath, basename
import collections
import re

__author__ = 'luiscberrocal'

APP_ROOT = dirname(dirname(abspath(__file__)))
SITE_NAME = basename(APP_ROOT)

def print_constants(vars_dict):
    od = collections.OrderedDict(sorted(vars_dict.items()))
    for var, value in od.items():
        regexp = '^[A-Z][A-Z_]+'
        match = re.search(regexp, var)
        if match:
            print('%-35s : %r' % (var, value))

def main():
    print_constants(globals())

if __name__ == '__main__':
    main()



import os
from pyjavaprops.javaproperties import JavaProperties
from pyjavaprops.settings.test import TEST_DATA_FOLDER

__author__ = 'luiscberrocal'

import unittest


class JavaPropertiesTestCase(unittest.TestCase):

    def setUp(self):
        filename = os.path.join(TEST_DATA_FOLDER, 'complex.properties')
        self.java_properties = JavaProperties()
        self.java_properties.load(open(filename))

    def test_value_with_spaces(self):
        self.assertEqual('Value14 With Spaces', self.java_properties['Key14'])
        self.assertEqual('Value01-test', self.java_properties['Key23'])

    def test_variable(self):
        self.assertEqual('Value01-test', self.java_properties['Key23'])

    def test_variable_dollar(self):
        self.assertEqual('Value01/path/to/myapp', self.java_properties['Key24'])

    def test_load(self):
        filename = os.path.join(TEST_DATA_FOLDER, 'simple.properties')
        simple_java_properties = JavaProperties()
        simple_java_properties.load(open(filename))
        print(simple_java_properties)


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

with open("README.md") as src:
    readme = src.read()

version = '0.1.3'

setup(
    name='pyjavaprops',
    version=version,
    description='Tool parse Java style properties file',
    long_description=readme,
    author='Luis Carlos Berrocal',
    author_email ='luis.berrocal.1942@gmail.com',
    packages=find_packages(),
    url='https://github.com/luiscberrocal/pyjavaprops',
    download_url = 'https://github.com/luiscberrocal/pyjavaprops/archive/v%s.zip' % version,
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.4',
    ],
    install_requires=[
    ],
    entry_points = {
        'console_scripts': ['list-settings=pyjavaprops.settings.base:main'],
    }
)